<?php

namespace Litecms\Pagedata\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Pagedata\Interfaces\PagedataRepositoryInterface;

class PagedataPublicController extends BaseController
{
    // use PagedataWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Pagedata\Interfaces\PagedataRepositoryInterface $pagedata
     *
     * @return type
     */
    public function __construct(PagedataRepositoryInterface $pagedata)
    {
        $this->repository = $pagedata;
        parent::__construct();
    }

    /**
     * Show pagedata's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $pagedatas = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$pagedata::$pagedata.names'))
            ->view('$pagedata::public.pagedata.index')
            ->data(compact('$pagedatas'))
            ->output();
    }

    /**
     * Show pagedata's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $pagedatas = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$pagedata::$pagedata.names'))
            ->view('$pagedata::public.pagedata.index')
            ->data(compact('$pagedatas'))
            ->output();
    }

    /**
     * Show pagedata.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $pagedata = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$pagedata->name . trans('$pagedata::$pagedata.name'))
            ->view('$pagedata::public.pagedata.show')
            ->data(compact('$pagedata'))
            ->output();
    }

}
