<?php

namespace Litecms\Pagedata\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Pagedata\Models\Pagedata;

class PagedataPolicy
{

    /**
     * Determine if the given user can view the pagedata.
     *
     * @param UserPolicy $user
     * @param Pagedata $pagedata
     *
     * @return bool
     */
    public function view(UserPolicy $user, Pagedata $pagedata)
    {
        if ($user->canDo('pagedata.pagedata.view') && $user->isAdmin()) {
            return true;
        }

        return $pagedata->user_id == user_id() && $pagedata->user_type == user_type();
    }

    /**
     * Determine if the given user can create a pagedata.
     *
     * @param UserPolicy $user
     * @param Pagedata $pagedata
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('pagedata.pagedata.create');
    }

    /**
     * Determine if the given user can update the given pagedata.
     *
     * @param UserPolicy $user
     * @param Pagedata $pagedata
     *
     * @return bool
     */
    public function update(UserPolicy $user, Pagedata $pagedata)
    {
        if ($user->canDo('pagedata.pagedata.edit') && $user->isAdmin()) {
            return true;
        }

        return $pagedata->user_id == user_id() && $pagedata->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given pagedata.
     *
     * @param UserPolicy $user
     * @param Pagedata $pagedata
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Pagedata $pagedata)
    {
        return $pagedata->user_id == user_id() && $pagedata->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given pagedata.
     *
     * @param UserPolicy $user
     * @param Pagedata $pagedata
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Pagedata $pagedata)
    {
        if ($user->canDo('pagedata.pagedata.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given pagedata.
     *
     * @param UserPolicy $user
     * @param Pagedata $pagedata
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Pagedata $pagedata)
    {
        if ($user->canDo('pagedata.pagedata.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
